==> haskell-warp-quic-0.0.0-223-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-FAb3ChJhzza7QLdnNkn5ph
key:                  warp-quic-0.0.0-FAb3ChJhzza7QLdnNkn5ph
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  3f7701e6737c2dfe1e4c117e8e3c7bea
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.2.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-FAb3ChJhzza7QLdnNkn5ph
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    http3-0.0.2-AFFaYvRo2EQEw2v9khhXZJ
    quic-0.1.6-3aSsVmMXGNHD6KB0ldN31e tls-1.8.0-33SvPTqEATs8WftP4GQ6hv
    wai-3.2.4-D36lDqHeOiN8tj0bmewMtj warp-3.3.30-5JFAGoCFAV66DE4hUxsVeL

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-quic-0.0.0-227-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-4kdcha1ZvLDLlYoOqCkBTr
key:                  warp-quic-0.0.0-4kdcha1ZvLDLlYoOqCkBTr
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  cc32fde494c6b44e4a7bb5bc04e6fc71
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.2.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-4kdcha1ZvLDLlYoOqCkBTr
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    http3-0.0.2-AUFD0i81Frb5WiAAai2rty
    quic-0.1.6-LfTgo5He9CEEgpYXb5tR42 tls-1.9.0-s2g5jVTg2V76pmTbCplsy
    wai-3.2.4-Etf4t8sbGx0KwC6RGtgsFP warp-3.3.30-9U264byqHhR6XEoBFOBIgi

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
